Crate hayro_write

Crate hayro_write 

A crate for converting PDF pages into either XObjects or a new page via pdf-writer.

This is an internal crate and not meant for external use. Therefore, it’s not very well-documented.

Re-exports

pub use hayro_syntax;

Structs

ChunkSettings
Settings that should be applied while writing a PDF file.
ExtractionQuery
An extraction query.
ExtractionResult
The result of an extraction.

Enums

ExtractionError
An error that occurred during page extraction.
ExtractionQueryType
A type of extraction query, indicating as what kind of object you want to extract the page.

Functions

extract
Apply the extraction queries to the given PDF and return the results.