pub struct ExtractionResult {
pub chunk: Chunk,
pub root_refs: Vec<Result<Ref, ExtractionError>>,
pub page_tree_parent_ref: Ref,
}Expand description
The result of an extraction.
Fields
chunk: ChunkThe chunk containing all objects as well as their dependencies.
root_refs: Vec<Result<Ref, ExtractionError>>The root references of the pages/XObject, one for each extraction query.
page_tree_parent_ref: RefThe reference to the page tree parent that was generated.